pubtools-exodus
===============

Utilities used by [release-engineering](https://github.com/release-engineering) publishing tools for interfacing with components of Red Hat's Content Delivery Network.

- [Source](https://github.com/release-engineering/pubtools-exodus)
- [Documentation](https://release-engineering.github.io/pubtools-exodus)


Development
-----------

Patches may be contributed via pull requests to
https://github.com/release-engineering/pubtools-exodus.

All changes must pass the automated test suite, along with various static
checks.

The [Black](https://black.readthedocs.io/) code style is enforced.
Enabling autoformatting via a pre-commit hook is recommended:

```
pip install black pre-commit
pre-commit install
```


License
-------

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.
